@@ -2,6 +2,8 @@ import re
 import json
 import logging
 import tempfile
+import urllib.parse
+from typing import Generator
 from pathlib import Path
 import git
 import requests
@@ -206,7 +208,9 @@ class OpenEuler():
             return None
 
             # ===================== 步骤1：基础清理 =====================
-        rpm_clean = rpm.strip()
+        rpm_decoded = urllib.parse.unquote(rpm)
+        rpm_decoded = urllib.parse.unquote(rpm_decoded)
+        rpm_clean = rpm_decoded.strip()
         # 移除结尾的 .rpm 后缀（忽略大小写）
         rpm_clean = re.sub(r"\.rpm$", "", rpm_clean, flags=re.IGNORECASE)
         # 移除结尾的架构后缀（x86_64/aarch64等）
@@ -215,50 +219,56 @@ class OpenEuler():
         # 移除末尾的空白/分隔符
         rpm_clean = rpm_clean.rstrip("-_.")
 
-        # ===================== 步骤2：定位版本段边界（原有逻辑） =====================
-        # 发行版标识（可按需扩展）
-        dist_identifiers = ["oe", "el", "centos", "fc", "sles", "debian", "ubuntu"]
-        dist_pattern = re.compile(rf"({'|'.join(dist_identifiers)})\d+", re.IGNORECASE)
-        # 版本段核心特征（纯数字/版本标识开头）
-        version_core_pattern = re.compile(r"^\d+(\.|-|_)|^v\d+|^svn\d+|^rc\d+|^beta\d+|^alpha\d+", re.IGNORECASE)
-
-        # 从后往前拆分，定位版本段起始位置
-        parts = rpm_clean.split("-")
-        version_start_idx = None
-        for i in reversed(range(len(parts))):
-            part = parts[i]
-            # 条件1：包含发行版标识（如 oe2403sp1、el8）→ 版本段起始
-            if dist_pattern.search(part):
-                version_start_idx = i
-                break
-            # 条件2：是纯版本核心（如 1.8.0.432、v3.22.0）→ 版本段起始
-            if version_core_pattern.match(part) or (part.replace(".", "").isdigit() and len(part) > 1):
-                version_start_idx = i
+        # ===================== 核心优化：步骤2：智能版本段识别（重构核心逻辑） =====================
+        # 定义版本段的特征正则（覆盖所有特殊版本格式）
+        # 匹配规则：
+        # 1. 纯数字开头（1.8.0、24.03、432）
+        # 2. 带版本前缀（v2.0.1、r1.2.3、beta1.0）
+        # 3. 发行版标识（oe2403、el8、LTS_SP1、b06）
+        # 4. 版本含特殊字符（_、.、- 组合）
+        version_pattern = re.compile(
+            r"""
+            (?:^|-)                                  # 匹配段开头（或分隔符-）
+            (?:
+                \d+[\._-]\d+                         # 基础版本（1.8.0、24_03、1-2）
+                |v\d+[\._-]\d+                       # 带v前缀（v2.0.1、v1_0）
+                |(oe|el|centos|fc|sles)\d+[\._-]?\w* # 发行版标识（oe2403sp1、el8_3）
+                |LTS[_-]SP\d+                        # 版本后缀（LTS_SP1、LTS-SP2）
+                |b\d+|rc\d+|beta\d+|alpha\d+         # 测试版本（b06、rc1、beta2）
+            )
+            (?:[\._-]\d+)*                           # 后续版本段（.432、_01、-3）
+            """,
+            re.VERBOSE | re.IGNORECASE
+        )
+        pkg_name = rpm_clean
+        version_start_pos = None
+        # 倒序遍历，找到第一个匹配版本段的位置
+        for i in range(len(rpm_clean) - 1, -1, -1):
+            if version_pattern.match(rpm_clean, pos=i):
+                version_start_pos = i
                 break
 
-        # 拼接初步包名（兜底逻辑）
-        if version_start_idx is not None and version_start_idx > 0:
-            pkg_name = "-".join(parts[:version_start_idx]).strip("-")
+        if version_start_pos is not None and version_start_pos > 0:
+            # 截取版本段之前的部分作为包名
+            pkg_name = rpm_clean[:version_start_pos].rstrip("-_.")
         else:
             log.warning(f"No valid version segment found for RPM: {rpm} (cleaned: {rpm_clean})")
-            pkg_name = rpm_clean
 
-        # ===================== 步骤3：核心优化：移除包名内的版本号 =====================
-        # 版本号正则：匹配 数字.数字.数字 或 纯数字段（如 1.3.261.0、22.0、11）
-        pkg_version_pattern = re.compile(
-            r"-(\d+(\.\d+)+|\d+)$",  # 匹配末尾的版本号（如 -1.3.261.0、-1.22.0、-11）
-            flags=re.IGNORECASE
-        )
-        # 循环清理：确保移除所有层级的版本号（如 java-1.8.0-openjdk → java-openjdk）
-        while pkg_version_pattern.search(pkg_name):
-            pkg_name = pkg_version_pattern.sub("", pkg_name)
+        nested_version_pattern = re.compile(r"-(\d+[\._-]\d+|v\d+)(?=-|$)")
+        while nested_version_pattern.search(pkg_name):
+            pkg_name = nested_version_pattern.sub("", pkg_name)
 
-        # 最终校验：避免空包名
+        # ===================== 步骤4：最终清理 =====================
+        # 1. 解码残留防护 + 合法字符过滤
+        pkg_name = urllib.parse.unquote(pkg_name)
+        pkg_name = re.sub(r'[^a-zA-Z0-9_\-\+\.]', '', pkg_name)
+        # 2. 移除末尾残留的分隔符
+        pkg_name = pkg_name.rstrip("-_.")
+        # 3. 兜底（避免空包名）
         if not pkg_name:
-            log.warning(f"Extracted empty pkg name for RPM: {rpm} (cleaned: {rpm_clean})")
             pkg_name = rpm_clean
 
-        log.debug(f"Extracted RPM name: {pkg_name} | Original: {rpm} | Cleaned: {rpm_clean}")
+        log.debug(f"Extracted RPM name: {pkg_name} | Original: {rpm} | Decoded: {rpm_decoded} | Cleaned: {rpm_clean}")
         return pkg_name
 
     def get_rpm_list(self,pkg_url):
@@ -509,6 +519,7 @@ class OpenEuler():
 
 if __name__ == "__main__":
     # 初始化获取器
+
     oe = OpenEuler()
     # rs = oe.get_openEuler_os_rpm2src("24.03-LTS-SP1", "x86_64")
     # print(len(rs.keys()))
@@ -533,10 +544,10 @@ if __name__ == "__main__":
     # rs=oe.get_openEuler_os_rpm_list("24.03-LTS-SP1", "x86_64")
     # for rpm in rs:
     #     print(f"{rpm}")
-    # rs = oe.get_rpm_list("https://diamond.oerv.ac.cn/openruyi/riscv64/riscv64/")
-    # for rpm_name in rs:
-    #     print(f"{rpm_name}")
-    # print(f"total {len(rs)} pkgs")
+    rs = oe.get_rpm_list("https://diamond.oerv.ac.cn/openruyi/riscv64/riscv64/")
+    for rpm_name in rs:
+        print(f"{rpm_name}")
+    print(f"total {len(rs)} pkgs")
     # rs=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
     # print(f"total {len(rs)} pkgs")
 
